==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/search/functions_6c.js <==
var searchData=
[
  ['lab',['lab',['../classplstream.html#ab077a5655c97d49056ac8cc6094beb4e',1,'plstream::lab()'],['../classplplot_1_1core_1_1PLStream.html#a61801a13b028375fde4c3a46315b5ce2',1,'plplot.core.PLStream.lab()']]],
  ['label',['label',['../interfaceplplot_1_1core_1_1PLCallbackLabel.html#aa118136f56391514fde8d9dd622adb71',1,'plplot::core::PLCallbackLabel']]],
  ['label_5fbox',['label_box',['../plbox_8c.html#a41910bb085ee0b959c492aee8dc76480',1,'plbox.c']]],
  ['label_5fbox_5fcustom',['label_box_custom',['../plbox_8c.html#a0e709b305271c726e295fc3fe4c890ac',1,'label_box_custom(const char *xopt, PLINT n_xticks, const PLFLT *xticks, const char *yopt, PLINT n_yticks, const PLFLT *yticks):&#160;plbox.c'],['../plplotP_8h.html#a0e709b305271c726e295fc3fe4c890ac',1,'label_box_custom(const char *xopt, PLINT n_xticks, const PLFLT *xticks, const char *yopt, PLINT n_yticks, const PLFLT *yticks):&#160;plbox.c']]],
  ['label_5fjava',['label_java',['../plplotjavacJAVA__wrap_8c.html#a1e978d236f3a0ee89e48546e40fc7fc5',1,'label_java(PLINT axis, PLFLT value, char *string, PLINT len, PLPointer data):&#160;plplotjavacJAVA_wrap.c'],['../plplotjavacJAVA__wrap_8c.html#a8c886a94a15e4337358b6af48fe3722e',1,'label_java(PLINT axis, PLFLT value, char *string, PLINT len, PLPointer PL_UNUSED(data)):&#160;plplotjavacJAVA_wrap.c']]],
  ['label_5freset',['label_reset',['../namespacePlframe.html#a93b6d4d8d32072e1f0af52614bf8356c',1,'Plframe']]],
  ['label_5fset',['label_set',['../namespacePlframe.html#a0bf33c9e233e6cac8488ad920e340e99',1,'Plframe']]],
  ['labelform',['labelform',['../tclAPI_8c.html#aa94e0f0c3f6c1dd0458280e48791bc27',1,'labelform(PLINT axis, PLFLT value, char *string, PLINT string_length, PLPointer data):&#160;tclAPI.c'],['../tclAPI_8c.html#a0f2bba504f4c307b7f6f4dbe132098b8',1,'labelform(PLINT axis, PLFLT value, char *string, PLINT string_length, PLPointer PL_UNUSED(data)):&#160;tclAPI.c']]],
  ['labelfunc_5foctave',['labelfunc_octave',['../plplot__octaveOCTAVE__wrap_8cxx.html#a89438106f388d4223b46dafd1661dfcc',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['leap_5fsecond_5ftai',['leap_second_TAI',['../qsastime_8c.html#a1edfb60a93bc2c3cbe71d4ead42bbff1',1,'qsastime.c']]],
  ['legend',['legend',['../classplstream.html#a27e76f10be0e1c2382e1664781513eee',1,'plstream::legend()'],['../classplplot_1_1core_1_1PLStream.html#a506a7ef60ea832db1bb5d20eec2b5bc5',1,'plplot.core.PLStream.legend()']]],
  ['legend_5fposition',['legend_position',['../pllegend_8c.html#ad6befa769f7cd5bdd75c96d8b6d11320',1,'pllegend.c']]],
  ['lightsource',['lightsource',['../classplstream.html#ae129dd5f46b40e6d0b3462633027e8ff',1,'plstream::lightsource()'],['../classplplot_1_1core_1_1PLStream.html#ad6925a48811f84d8d68dc2b5e2c082ae',1,'plplot.core.PLStream.lightsource()']]],
  ['line',['line',['../classplstream.html#ab94015dfd576f331c581d6389368d013',1,'plstream::line()'],['../classplplot_1_1core_1_1PLStream.html#aaed50b3ac0cc643206377e3b867f0318',1,'plplot.core.PLStream.line()']]],
  ['line3',['line3',['../classplstream.html#a2e15a0c1823c1c405353603ed7311ce4',1,'plstream::line3()'],['../classplplot_1_1core_1_1PLStream.html#aac6cbede200f4ceb5630f36886c1d99c',1,'plplot.core.PLStream.line3()']]],
  ['load_5fascii',['load_ascii',['../classoctave__swig__type.html#a3e5834ee0a43578b84a0c56d03550921',1,'octave_swig_type::load_ascii()'],['../classoctave__swig__ref.html#af7b48be17865bae8baa08816dda0d634',1,'octave_swig_ref::load_ascii()'],['../classoctave__swig__packed.html#a25eba042956391d6ebaa45814594b994',1,'octave_swig_packed::load_ascii()']]],
  ['load_5fbinary',['load_binary',['../classoctave__swig__type.html#a167e26a77f3c93b6c4540a1145b0769d',1,'octave_swig_type::load_binary()'],['../classoctave__swig__ref.html#aa5a9833a6de68925a8c31350d1495341',1,'octave_swig_ref::load_binary()'],['../classoctave__swig__packed.html#aa8bc33f2c6491a80789b23efecd52c56',1,'octave_swig_packed::load_binary()']]],
  ['load_5fmembers',['load_members',['../classoctave__swig__type.html#a8ca6a0956ca00660e968a53103e2177f',1,'octave_swig_type::load_members(const swig_octave_class *c, member_map &amp;out) const '],['../classoctave__swig__type.html#aa95acd3ace59572796f2aae2ceb5a97c',1,'octave_swig_type::load_members(member_map &amp;out) const ']]],
  ['locate',['Locate',['../classwxPLplotWindow.html#a55a6d13db71785af4c5f467fb035eded',1,'wxPLplotWindow']]],
  ['log_5fdebug',['Log_Debug',['../wxwidgets_8cpp.html#ab1277ea7aa81e2c31a4cbbe04e3f802b',1,'Log_Debug(const char *fmt,...):&#160;wxwidgets.cpp'],['../wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b',1,'Log_Debug(const char *fmt,...):&#160;wxwidgets.cpp']]],
  ['log_5fverbose',['Log_Verbose',['../wxwidgets_8cpp.html#a4ac7c6cbc53d0a1a1180d76836d0ae15',1,'Log_Verbose(const char *fmt,...):&#160;wxwidgets.cpp'],['../wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15',1,'Log_Verbose(const char *fmt,...):&#160;wxwidgets.cpp']]],
  ['loopbackcmd',['loopbackCmd',['../tclAPI_8c.html#a0a549425032c27fb11723dffdf716276',1,'loopbackCmd(ClientData, Tcl_Interp *, int, const char **):&#160;tclAPI.c'],['../tclAPI_8c.html#a02b9f1947656e4ef3bde25c4630ebf89',1,'loopbackCmd(ClientData PL_UNUSED(clientData), Tcl_Interp *interp, int argc, const char **argv):&#160;tclAPI.c']]],
  ['lor_5fml_5flist',['lor_ml_list',['../plplot__impl_8c.html#ad7347cc3d9fd9feda1a060282b7b03d1',1,'plplot_impl.c']]],
  ['lpi_5fbuild',['lpi_build',['../lpi_8c.html#a4c00e1758de94a10b64beb116e9fa1e6',1,'lpi_build(delaunay *d):&#160;lpi.c'],['../nn_8h.html#a4c00e1758de94a10b64beb116e9fa1e6',1,'lpi_build(delaunay *d):&#160;lpi.c']]],
  ['lpi_5fdestroy',['lpi_destroy',['../lpi_8c.html#a359a8a845bfc59becd6a63da1f5ba589',1,'lpi_destroy(lpi *l):&#160;lpi.c'],['../nn_8h.html#a359a8a845bfc59becd6a63da1f5ba589',1,'lpi_destroy(lpi *l):&#160;lpi.c']]],
  ['lpi_5finterpolate_5fpoint',['lpi_interpolate_point',['../lpi_8c.html#aabe3dd89c72c137b39e4a149b51b3745',1,'lpi_interpolate_point(lpi *l, point *p):&#160;lpi.c'],['../nn_8h.html#aabe3dd89c72c137b39e4a149b51b3745',1,'lpi_interpolate_point(lpi *l, point *p):&#160;lpi.c']]],
  ['lpi_5finterpolate_5fpoints',['lpi_interpolate_points',['../lpi_8c.html#a4d0ca67c0140fbb21d9f1fac3caeed5d',1,'lpi_interpolate_points(int nin, point pin[], int nout, point pout[]):&#160;lpi.c'],['../nn_8h.html#aa565f0ca66c3cc760b9112c9ac125dbe',1,'lpi_interpolate_points(int nin, point pin[], int nout, point pout[]):&#160;lpi.c']]],
  ['lsq',['lsq',['../csa_8c.html#a269fc7b71b2e8e55d3ac4c8fb387411f',1,'csa.c']]],
  ['lsty',['lsty',['../classplstream.html#a4a571952c811953cba099f45bcbe3eed',1,'plstream::lsty()'],['../classplplot_1_1core_1_1PLStream.html#a972e089112cb93d4497c523cfa1c26fa',1,'plplot.core.PLStream.lsty()']]],
  ['lt_5fdlerror',['lt_dlerror',['../ltdl__win32_8c.html#a9cd81a4030d3a2a47f9fc14ac9bbdd03',1,'lt_dlerror():&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a84fd997df6e671d145fec31d3e070337',1,'lt_dlerror():&#160;ltdl_win32.c']]],
  ['lt_5fdlexit',['lt_dlexit',['../ltdl__win32_8c.html#a6e0648daaed7ad080a476bde9025f26b',1,'lt_dlexit(void):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#aee8b4194e1c4e42de2db5ec953d8501a',1,'lt_dlexit(void):&#160;ltdl_win32.c']]],
  ['lt_5fdlinit',['lt_dlinit',['../ltdl__win32_8c.html#aeb27a88b012cb1446f31570ff74dbdd4',1,'lt_dlinit(void):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a5d041a11342a5e82bcb1456332957300',1,'lt_dlinit(void):&#160;ltdl_win32.c']]],
  ['lt_5fdlmakeresident',['lt_dlmakeresident',['../ltdl__win32_8c.html#a52d9c03d1a20e457a6bf60fe73b4c6a8',1,'lt_dlmakeresident(lt_dlhandle handle):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a27f994e13bb1fa8980244f212c984f03',1,'lt_dlmakeresident(lt_dlhandle handle):&#160;ltdl_win32.c']]],
  ['lt_5fdlopenext',['lt_dlopenext',['../ltdl__win32_8c.html#a9bcfb64a23ceb6d73f536372f4a52e42',1,'lt_dlopenext(char *dllname):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a2b4aade23de5404819ba28542e1ece8a',1,'lt_dlopenext(char *dllname):&#160;ltdl_win32.c']]],
  ['lt_5fdlsym',['lt_dlsym',['../ltdl__win32_8c.html#a0d3d2c13b6fb1c2321ea4fe4a8d6f249',1,'lt_dlsym(lt_dlhandle dlhandle, const char *symbol):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a0e3050247af5c5c66dbbd42eb7702cd4',1,'lt_dlsym(lt_dlhandle dlhandle, const char *symbol):&#160;ltdl_win32.c']]],
  ['lua_5fdeclare_5ftypemap_5farr_5ffn',['LUA_DECLARE_TYPEMAP_ARR_FN',['../plplotluacLUA__wrap_8c.html#a8c16dccb10308adfacc5fffd46e21e04',1,'LUA_DECLARE_TYPEMAP_ARR_FN(double, double):&#160;plplotluacLUA_wrap.c'],['../plplotluacLUA__wrap_8c.html#ad67fd18f3472dadb9be9853c6ae2b7c9',1,'LUA_DECLARE_TYPEMAP_ARR_FN(int, int):&#160;plplotluacLUA_wrap.c']]]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/search/functions_6c.js <==
var searchData=
[
  ['lab',['lab',['../classplstream.html#ab077a5655c97d49056ac8cc6094beb4e',1,'plstream::lab()'],['../classplplot_1_1core_1_1PLStream.html#a61801a13b028375fde4c3a46315b5ce2',1,'plplot.core.PLStream.lab()']]],
  ['label',['label',['../interfaceplplot_1_1core_1_1PLCallbackLabel.html#aa118136f56391514fde8d9dd622adb71',1,'plplot::core::PLCallbackLabel']]],
  ['label_5fbox',['label_box',['../plbox_8c.html#a41910bb085ee0b959c492aee8dc76480',1,'plbox.c']]],
  ['label_5fbox_5fcustom',['label_box_custom',['../plbox_8c.html#a0e709b305271c726e295fc3fe4c890ac',1,'label_box_custom(const char *xopt, PLINT n_xticks, const PLFLT *xticks, const char *yopt, PLINT n_yticks, const PLFLT *yticks):&#160;plbox.c'],['../plplotP_8h.html#a0e709b305271c726e295fc3fe4c890ac',1,'label_box_custom(const char *xopt, PLINT n_xticks, const PLFLT *xticks, const char *yopt, PLINT n_yticks, const PLFLT *yticks):&#160;plbox.c']]],
  ['label_5fjava',['label_java',['../plplotjavacJAVA__wrap_8c.html#a1e978d236f3a0ee89e48546e40fc7fc5',1,'label_java(PLINT axis, PLFLT value, char *string, PLINT len, PLPointer data):&#160;plplotjavacJAVA_wrap.c'],['../plplotjavacJAVA__wrap_8c.html#a8c886a94a15e4337358b6af48fe3722e',1,'label_java(PLINT axis, PLFLT value, char *string, PLINT len, PLPointer PL_UNUSED(data)):&#160;plplotjavacJAVA_wrap.c']]],
  ['label_5freset',['label_reset',['../namespacePlframe.html#a93b6d4d8d32072e1f0af52614bf8356c',1,'Plframe']]],
  ['label_5fset',['label_set',['../namespacePlframe.html#a0bf33c9e233e6cac8488ad920e340e99',1,'Plframe']]],
  ['labelform',['labelform',['../tclAPI_8c.html#aa94e0f0c3f6c1dd0458280e48791bc27',1,'labelform(PLINT axis, PLFLT value, char *string, PLINT string_length, PLPointer data):&#160;tclAPI.c'],['../tclAPI_8c.html#a0f2bba504f4c307b7f6f4dbe132098b8',1,'labelform(PLINT axis, PLFLT value, char *string, PLINT string_length, PLPointer PL_UNUSED(data)):&#160;tclAPI.c']]],
  ['labelfunc_5foctave',['labelfunc_octave',['../plplot__octaveOCTAVE__wrap_8cxx.html#a89438106f388d4223b46dafd1661dfcc',1,'plplot_octaveOCTAVE_wrap.cxx']]],
  ['lastwascached',['lastWasCached',['../classFontGrabber.html#a03558c93c0c9bac08d90ba76397ac237',1,'FontGrabber']]],
  ['leap_5fsecond_5ftai',['leap_second_TAI',['../qsastime_8c.html#a1edfb60a93bc2c3cbe71d4ead42bbff1',1,'qsastime.c']]],
  ['legend',['legend',['../classplstream.html#a27e76f10be0e1c2382e1664781513eee',1,'plstream::legend()'],['../classplplot_1_1core_1_1PLStream.html#a506a7ef60ea832db1bb5d20eec2b5bc5',1,'plplot.core.PLStream.legend()']]],
  ['legend_5fposition',['legend_position',['../pllegend_8c.html#ad6befa769f7cd5bdd75c96d8b6d11320',1,'pllegend.c']]],
  ['lightsource',['lightsource',['../classplstream.html#ae129dd5f46b40e6d0b3462633027e8ff',1,'plstream::lightsource()'],['../classplplot_1_1core_1_1PLStream.html#ad6925a48811f84d8d68dc2b5e2c082ae',1,'plplot.core.PLStream.lightsource()']]],
  ['line',['line',['../classplstream.html#ab94015dfd576f331c581d6389368d013',1,'plstream::line()'],['../classplplot_1_1core_1_1PLStream.html#aaed50b3ac0cc643206377e3b867f0318',1,'plplot.core.PLStream.line()']]],
  ['line3',['line3',['../classplstream.html#a2e15a0c1823c1c405353603ed7311ce4',1,'plstream::line3()'],['../classplplot_1_1core_1_1PLStream.html#aac6cbede200f4ceb5630f36886c1d99c',1,'plplot.core.PLStream.line3()']]],
  ['load_5fascii',['load_ascii',['../classoctave__swig__type.html#a3e5834ee0a43578b84a0c56d03550921',1,'octave_swig_type::load_ascii()'],['../classoctave__swig__ref.html#af7b48be17865bae8baa08816dda0d634',1,'octave_swig_ref::load_ascii()'],['../classoctave__swig__packed.html#a25eba042956391d6ebaa45814594b994',1,'octave_swig_packed::load_ascii()']]],
  ['load_5fbinary',['load_binary',['../classoctave__swig__type.html#a167e26a77f3c93b6c4540a1145b0769d',1,'octave_swig_type::load_binary()'],['../classoctave__swig__ref.html#aa5a9833a6de68925a8c31350d1495341',1,'octave_swig_ref::load_binary()'],['../classoctave__swig__packed.html#aa8bc33f2c6491a80789b23efecd52c56',1,'octave_swig_packed::load_binary()']]],
  ['load_5fmembers',['load_members',['../classoctave__swig__type.html#a8ca6a0956ca00660e968a53103e2177f',1,'octave_swig_type::load_members(const swig_octave_class *c, member_map &amp;out) const '],['../classoctave__swig__type.html#aa95acd3ace59572796f2aae2ceb5a97c',1,'octave_swig_type::load_members(member_map &amp;out) const ']]],
  ['locate',['Locate',['../classwxPLDevice.html#a633da81974bca97abbe5a8b6c18b6509',1,'wxPLDevice']]],
  ['log_5fdebug',['Log_Debug',['../wxwidgets_8cpp.html#ab1277ea7aa81e2c31a4cbbe04e3f802b',1,'Log_Debug(const char *fmt,...):&#160;wxwidgets.cpp'],['../wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b',1,'Log_Debug(const char *fmt,...):&#160;wxwidgets.cpp']]],
  ['log_5fverbose',['Log_Verbose',['../wxwidgets_8cpp.html#a4ac7c6cbc53d0a1a1180d76836d0ae15',1,'Log_Verbose(const char *fmt,...):&#160;wxwidgets.cpp'],['../wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15',1,'Log_Verbose(const char *fmt,...):&#160;wxwidgets.cpp']]],
  ['loopbackcmd',['loopbackCmd',['../tclAPI_8c.html#a0a549425032c27fb11723dffdf716276',1,'loopbackCmd(ClientData, Tcl_Interp *, int, const char **):&#160;tclAPI.c'],['../tclAPI_8c.html#a02b9f1947656e4ef3bde25c4630ebf89',1,'loopbackCmd(ClientData PL_UNUSED(clientData), Tcl_Interp *interp, int argc, const char **argv):&#160;tclAPI.c']]],
  ['lor_5fml_5flist',['lor_ml_list',['../plplot__impl_8c.html#ad7347cc3d9fd9feda1a060282b7b03d1',1,'plplot_impl.c']]],
  ['lpi_5fbuild',['lpi_build',['../lpi_8c.html#a4c00e1758de94a10b64beb116e9fa1e6',1,'lpi_build(delaunay *d):&#160;lpi.c'],['../nn_8h.html#a4c00e1758de94a10b64beb116e9fa1e6',1,'lpi_build(delaunay *d):&#160;lpi.c']]],
  ['lpi_5fdestroy',['lpi_destroy',['../lpi_8c.html#a359a8a845bfc59becd6a63da1f5ba589',1,'lpi_destroy(lpi *l):&#160;lpi.c'],['../nn_8h.html#a359a8a845bfc59becd6a63da1f5ba589',1,'lpi_destroy(lpi *l):&#160;lpi.c']]],
  ['lpi_5finterpolate_5fpoint',['lpi_interpolate_point',['../lpi_8c.html#aabe3dd89c72c137b39e4a149b51b3745',1,'lpi_interpolate_point(lpi *l, point *p):&#160;lpi.c'],['../nn_8h.html#aabe3dd89c72c137b39e4a149b51b3745',1,'lpi_interpolate_point(lpi *l, point *p):&#160;lpi.c']]],
  ['lpi_5finterpolate_5fpoints',['lpi_interpolate_points',['../lpi_8c.html#a4d0ca67c0140fbb21d9f1fac3caeed5d',1,'lpi_interpolate_points(int nin, point pin[], int nout, point pout[]):&#160;lpi.c'],['../nn_8h.html#aa565f0ca66c3cc760b9112c9ac125dbe',1,'lpi_interpolate_points(int nin, point pin[], int nout, point pout[]):&#160;lpi.c']]],
  ['lsq',['lsq',['../csa_8c.html#a269fc7b71b2e8e55d3ac4c8fb387411f',1,'csa.c']]],
  ['lsty',['lsty',['../classplstream.html#a4a571952c811953cba099f45bcbe3eed',1,'plstream::lsty()'],['../classplplot_1_1core_1_1PLStream.html#a972e089112cb93d4497c523cfa1c26fa',1,'plplot.core.PLStream.lsty()']]],
  ['lt_5fdlerror',['lt_dlerror',['../ltdl__win32_8c.html#a9cd81a4030d3a2a47f9fc14ac9bbdd03',1,'lt_dlerror():&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a84fd997df6e671d145fec31d3e070337',1,'lt_dlerror():&#160;ltdl_win32.c']]],
  ['lt_5fdlexit',['lt_dlexit',['../ltdl__win32_8c.html#a6e0648daaed7ad080a476bde9025f26b',1,'lt_dlexit(void):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#aee8b4194e1c4e42de2db5ec953d8501a',1,'lt_dlexit(void):&#160;ltdl_win32.c']]],
  ['lt_5fdlinit',['lt_dlinit',['../ltdl__win32_8c.html#aeb27a88b012cb1446f31570ff74dbdd4',1,'lt_dlinit(void):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a5d041a11342a5e82bcb1456332957300',1,'lt_dlinit(void):&#160;ltdl_win32.c']]],
  ['lt_5fdlmakeresident',['lt_dlmakeresident',['../ltdl__win32_8c.html#a52d9c03d1a20e457a6bf60fe73b4c6a8',1,'lt_dlmakeresident(lt_dlhandle handle):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a27f994e13bb1fa8980244f212c984f03',1,'lt_dlmakeresident(lt_dlhandle handle):&#160;ltdl_win32.c']]],
  ['lt_5fdlopenext',['lt_dlopenext',['../ltdl__win32_8c.html#a9bcfb64a23ceb6d73f536372f4a52e42',1,'lt_dlopenext(char *dllname):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a2b4aade23de5404819ba28542e1ece8a',1,'lt_dlopenext(char *dllname):&#160;ltdl_win32.c']]],
  ['lt_5fdlsym',['lt_dlsym',['../ltdl__win32_8c.html#a0d3d2c13b6fb1c2321ea4fe4a8d6f249',1,'lt_dlsym(lt_dlhandle dlhandle, const char *symbol):&#160;ltdl_win32.c'],['../ltdl__win32_8h.html#a0e3050247af5c5c66dbbd42eb7702cd4',1,'lt_dlsym(lt_dlhandle dlhandle, const char *symbol):&#160;ltdl_win32.c']]],
  ['lua_5fdeclare_5ftypemap_5farr_5ffn',['LUA_DECLARE_TYPEMAP_ARR_FN',['../plplotluacLUA__wrap_8c.html#a8c16dccb10308adfacc5fffd46e21e04',1,'LUA_DECLARE_TYPEMAP_ARR_FN(double, double):&#160;plplotluacLUA_wrap.c'],['../plplotluacLUA__wrap_8c.html#ad67fd18f3472dadb9be9853c6ae2b7c9',1,'LUA_DECLARE_TYPEMAP_ARR_FN(int, int):&#160;plplotluacLUA_wrap.c']]]
];
